16.118. cdist-type__pacman_conf_integrate(7) — cdist 6.9.4 documentation

# 16.118. cdist-type__pacman_conf_integrate(7)

## 16.118.1. NAME

cdist-type__pacman_conf_integrate - Integrate default pacman.conf to cdist conform and vice versa

## 16.118.2. DESCRIPTION

The type allows you to convert the default pacman.conf to a cdist conform one and vice versa

## 16.118.3. REQUIRED PARAMETERS

None.

## 16.118.4. OPTIONAL PARAMETERS

state

  'present' or 'absent', defaults to 'present'

## 16.118.5. EXAMPLES

    # Convert normal to cdist conform
    __pacman_conf_integrate convert

    # Convert cdist conform to normal
    __pacman_conf_integrate convert --state absent

## 16.118.6. SEE ALSO

grep(1)

## 16.118.7. AUTHORS

Dominique Roux <dominique.roux4@gmail.com>

## 16.118.8. COPYING

Copyright (C) 2015 Dominique Roux. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.